#include <cstdint>
#include <iostream>
#include <algorithm>
#include <cassert>

const uint32_t MAX_X = 1e9 + 10;
const uint32_t INF = MAX_X + 1;

struct Node {
	static const uint32_t MAX_MEM = 1e7;
	static Node node_mem[];
	static Node *memPtr;

	uint32_t low, high;

	Node *l, *r;
	uint32_t maxV;
	uint32_t minV;
	uint32_t lazy;
	uint64_t sum;

	Node(): low(0), high(0), l(nullptr), r(nullptr), maxV(INF), minV(INF), lazy(0), sum(0) {}

	inline uint64_t len() const {
		return high - low + 1;
	}

	static Node* get_node(uint32_t pL, uint32_t pH) {
		memPtr->low = pL;
		memPtr->high = pH;
		return memPtr++;
	}

	void push_lazy() {
		if (low == high) {
			return;
		}
		uint32_t mid =(low + high) / 2;
		l = l ? l : get_node(low, mid);
		r = r ? r : get_node(mid + 1, high);
		if (lazy) {
			l->maxV = l->lazy = lazy;
			l->sum = l->len() * lazy;
			r->maxV = r->lazy = lazy;
			r->sum = r->len() * lazy;
			lazy = 0;
		}
	}

	void update(uint32_t qL, uint32_t qH, uint32_t qV) {
		if ((qL <= low) && (high <= qH)) {
			assert(maxV > qV);
			maxV = minV = lazy = qV;
			sum = len() * maxV;
		} else if ((high < qL) || (qH < low)) {
			return;
		} else {
			push_lazy();
			l->update(qL, qH, qV);
			r->update(qL, qH, qV);
			maxV = std::max(l->maxV, r->maxV);
			minV = std::min(l->minV, r->minV);
			sum = l->sum + r->sum;
		}
	}
	uint64_t sum_query(uint32_t qL, uint32_t qH) {
		if ((qL <= low) && (high <= qH)) {
			return sum;
		} else if ((high < qL) || (qH < low)) {
			return 0;
		} else {
			push_lazy();
			return l->sum_query(qL, qH) + r->sum_query(qL, qH);
		}
	}
	uint64_t max_query(uint32_t qL, uint32_t qH) {
		if ((qL <= low) && (high <= qH)) {
			return maxV;
		} else if ((high < qL) || (qH < low)) {
			return 0;
		} else {
			push_lazy();
			return std::max(l->max_query(qL, qH), r->max_query(qL, qH));
		}
	}
	uint32_t first_ind_more(uint32_t x, uint32_t v) {
		if (maxV <= v) {
			return INF;
		}
		if (x > high) {
			return INF;
		} else if (high == low) {
			return maxV > v ? high : INF;
		} else {
			push_lazy();
			uint32_t ans = l->first_ind_more(x, v);
			if (ans < INF) {
				return ans;
			} else {
				return r->first_ind_more(x, v);
			}
		}
	}
	uint32_t first_ind_less(uint32_t x, uint32_t v) {
		//std::cerr << "min [" << low << " " << high << "] " << minV <<std::endl;
		if (minV >= v) {
			return INF;
		}
		if (x > high) {
			return INF;
		} else if (high == low) {
			return minV < v ? high : INF;
		} else {
			push_lazy();
			uint32_t ans = l->first_ind_less(x, v);
			if (ans < INF) {
				return ans;
			} else {
				return r->first_ind_less(x, v);
			}
		}
	}

};

Node Node::node_mem[Node::MAX_MEM];
Node* Node::memPtr = Node::node_mem;
Node *root = Node::get_node(0, MAX_X);
uint32_t len, k, n;

void add_station(int l, int price) {
	//price -= 200;
	int r = l + k - 1;
	int i1 = root->first_ind_more(l, price);
	if (i1 > r) {
		return;
	}
	int i2 = root->first_ind_less(i1, price);

	i2 = std::min(i2 - 1, r);
	//std::cerr << "price " << price << " at " << l << " dominates [";
	//std::cerr << i1 << ";" << i2 << "]\n";
	root->update(i1, i2, price);
}

long long get_ans() {
	return root->sum_query(0, len - 1);
}

long long init(int L, int K, int N, int *startPos, int *startPrice) {
	len = L;
	k = K;
	n = N;
	for (uint32_t i = 0;i < n;i++) {
		add_station(startPos[i], startPrice[i]);
	}
	return get_ans();
}


long long addStation(int l, int price) {
	add_station(l, price);
	return get_ans();
}

