#include <iostream>
#include <cstdint>
#include <algorithm>
#include <vector>
#include <utility>

#pragma GCC optimize("Ofast")

const uint32_t MAX_N = 1e5;
const uint32_t MAX_P = 1e6 + 10;
const uint32_t OFFSET = 2 * MAX_P;
const uint32_t MAX_X = 2 * OFFSET;

typedef std::pair<uint32_t, uint32_t> ValT;

static ValT combine(const ValT &a, const ValT &b) {
	if (a.first > b.first) {
		return a;
	} else if (b.first > a.first) {
		return b;
	} else {
		return {a.first, a.second + b.second};
	}
}


template <size_t N>
class SegmentTree {
private:
	ValT val[2 * N];

public:
	SegmentTree() {
		std::fill(val, val + 2 * N, std::make_pair(0, 1));
	}

	void update(uint32_t i, uint32_t deltaV) { ///ICE 2.5 if I am not mistaken
		i += N;
		val[i].first += deltaV;
		for (i >>= 1;i > 0;i >>= 1) {
			val[i] = combine(val[i * 2], val[i * 2 + 1]);
		}
	}
	ValT query(uint32_t l, uint32_t r) {
		ValT ans = {0, 0};

		for (l += N, r += N;l < r;l >>= 1, r >>= 1) {
			if (l & 1)  {
				ans = combine(ans, val[l++]);
			}
			if (r & 1) {
				ans = combine(ans, val[--r]);
			}
		}
		return ans;
	}
};

SegmentTree<MAX_X> tree;
bool points[MAX_X];
std::vector<uint32_t> eastEnd[MAX_X];

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);

	uint32_t signCnt;
	std::cin >> signCnt;
	for (uint32_t i = 0;i < signCnt;i++) {
		int32_t pRaw;
		uint32_t e, w;
		std::cin >> pRaw >> w >> e;
		uint32_t p = pRaw + OFFSET;
		uint32_t pE = p + e;
		uint32_t pW = p - w;
		points[pE] = points[pW] = true;
		eastEnd[pW].push_back(pE);
		tree.update(pE, 1);
		tree.update(pW, 1);
	}
}

ValT ans = {0, 0};
void solve() {
	for (uint32_t i = 0;i < MAX_X;i++) {
		if (!points[i]) {
			continue;
		}

		uint32_t curCnt = tree.query(i, i + 1).first;
		//std::cerr << (int32_t)(i - OFFSET) << " " << curCnt << "\n";
		for (uint32_t j : eastEnd[i]) {
			tree.update(j, -1);
		}
		ValT cur = tree.query(i + 1, MAX_X);
		cur.first += curCnt;
		ans = combine(cur, ans);

		for (uint32_t j : eastEnd[i]) {
			tree.update(j, 1);
		}
	}
}

int main() {
	input();
	//solve();
	std::cout << ans.first << " " << ans.second << "\n";
}
